(indent-for-tab-command)
(forward-line)
(beginning-of-line)
(indent-for-tab-command)
(forward-line)
(forward-line)
(beginning-of-line)
(indent-for-tab-command)
(forward-line)
(save-buffer)
(save-buffers-kill-emacs)
